/*
 *    Copyright (c) 2016 by  Maciej Wiecierzewski
 */

function CloudPlatform(x, y, w, h, game, mainGroup, frontSpriteGroup, backSpriteGroup)
{
    this.game = game;

    var sprite = game.add.tileSprite(x, y, w, h, 'cloud_tile');
    sprite.anchor.x = 0.5;

    sprite.cloud = this;
    sprite.updatePos = function() { this.cloud.updatePos(); };

    game.physics.arcade.enable(sprite);
    sprite.body.immovable = true;
    sprite.body.customSeparateX = true;
    sprite.body.customSeparateY = true;
    sprite.body.checkCollision.left = false;
    sprite.body.checkCollision.right = false;

    mainGroup.add(sprite);
    this.sprite = sprite;

    var cloudBack = game.add.sprite(x, y, 'cloud_back');
    backSpriteGroup.add(cloudBack);
    this.cloudBack = cloudBack;

    var cloudFront = game.add.sprite(x, y, 'cloud_front');
    frontSpriteGroup.add(cloudFront);
    this.cloudFront = cloudFront;
}

//------------------------------------------------------------------------------

CloudPlatform.prototype.setMotionPath = function(motionPath, speedFactor)
{
    var game = this.game;
    var body = this.sprite.body;

    var tweenX = game.add.tween(body);
    var tweenY = game.add.tween(body);

    for(var i = 0; i < motionPath.length; i++)
    {
        tweenX.to( { x: motionPath[i].x }, motionPath[i].speed*speedFactor, motionPath[i].xEase);
        tweenY.to( { y: motionPath[i].y }, motionPath[i].speed*speedFactor, motionPath[i].yEase);
    }

    tweenX.loop();
    tweenY.loop();

    this.tweenX = tweenX;
    this.tweenY = tweenY;
}

//------------------------------------------------------------------------------

CloudPlatform.prototype.start = function()
{
    this.tweenX.start();
    this.tweenY.start();
}

//------------------------------------------------------------------------------

CloudPlatform.prototype.stop = function()
{
    this.tweenX.stop();
    this.tweenY.stop();
}

//------------------------------------------------------------------------------

CloudPlatform.prototype.updatePos = function()
{
    var x = this.sprite.body.x;
    var y = this.sprite.body.y;

    this.cloudBack.x = x-30;
    this.cloudBack.y = y-85;

    this.cloudFront.x = x-25;
    this.cloudFront.y = y-90;
}
