/*
 *    Copyright (c) 2016 by  Maciej Wiecierzewski
 */

PlayerAnimation.States = Object.freeze({ STAY: 1, WALK: 2, START_WALK: 3,
     END_WALK: 4, JUMP: 5, FALL: 6, HIT_GROUND: 7 });

function PlayerAnimation(sprite)
{
    this.sprite = sprite;
    this.state = PlayerAnimation.States.STAY;
    this.animCount = 0;
    this.onWalkBegin = function() {};
    this.onWalkEnd = function() {};

    sprite.animations.play("walk_start", 30, false);
}

//------------------------------------------------------------------------------

PlayerAnimation.prototype.setState = function(newState)
{
    var States = PlayerAnimation.States;

    var prevState = this._state;
    this._state = newState;

    if(prevState != newState)
    {
        if(prevState === States.WALK)
            this.onWalkEnd();
        else if(newState === States.WALK)
            this.onWalkBegin();
    }
}

Object.defineProperty(PlayerAnimation.prototype, 'state', {
    get: function() {   return this._state;    },
    set: PlayerAnimation.prototype.setState
});

//------------------------------------------------------------------------------

// updated animation state; called on each frame rendered
PlayerAnimation.prototype.update = function()
{
    var States = PlayerAnimation.States;
    var sprite = this.sprite;

    if(this.state === States.START_WALK)
    {
        if(this.animCount === 0)
        {
            this.state = States.WALK;
            sprite.animations.play('walk', 30, true);
            sprite.animations.frame = 22;
        }

        this.animCount--;
    }
    else if(this.state === States.END_WALK)
    {
        if(sprite.animations.currentAnim.isPlaying === false)
        {
            this.state = States.STAY;
        }
    }
    else if(this.state === States.HIT_GROUND)
    {
        if(this.animCount === 0)
        {
            this.state = States.STAY;

            sprite.animations.play("walk_start", 30, false);
            if(this.stop)
                sprite.animations.stop();
        }

        this.animCount--;
    }
}

//------------------------------------------------------------------------------

PlayerAnimation.prototype.startWalk = function()
{
    var States = PlayerAnimation.States;

    this.sprite.animations.play('walk_start', 30, false);
    this.state = States.START_WALK;
    this.animCount = 3;
}

//------------------------------------------------------------------------------

PlayerAnimation.prototype.stopWalk = function()
{
    var States = PlayerAnimation.States;

    if(this.state === States.WALK)
    {
        var frame = this.sprite.animations.frame;
        var startFrame;

        if(frame >= 12 && frame <= 27)
        {
            startFrame = Math.abs(12 - frame);
            this.sprite.animations.play('walk_end_left', 30, false);
        }
        else
        {
            startFrame = Math.abs(28 - (frame <= 6 ? frame+30 : frame));
            this.sprite.animations.play('walk_end_right', 30, false);
        }

        this.sprite.animations.frame = startFrame+1;
    }

    this.state = States.END_WALK;
}

//------------------------------------------------------------------------------

PlayerAnimation.prototype.jump = function()
{
    var States = PlayerAnimation.States;

    this.sprite.animations.play('jump_begin', 30, false);
    this.state = States.JUMP;
}

//------------------------------------------------------------------------------

PlayerAnimation.prototype.fall = function()
{
    var States = PlayerAnimation.States;

    //this.sprite.animations.stop();
    this.state = States.FALL;
}

//------------------------------------------------------------------------------

PlayerAnimation.prototype.hitGround = function()
{
    var States = PlayerAnimation.States;

    this.sprite.animations.play('jump_end', 30, false);
    this.state = States.HIT_GROUND;
    this.animCount = 28;
    this.stop = true;
}
