/*
 *    Copyright (c) 2016 by  Maciej Wiecierzewski
 */

GameState.prototype.create = function()
{
    var game = this.game;

    var levelData = game.cache.getJSON('level_data');

    this.score = 0;
    this.maxScore = levelData.bubbles.length * this.points;

    game.physics.startSystem(Phaser.Physics.ARCADE);
    game.world.setBounds(0, 0, 2500, 1540);

    // adding game objects:
    // - sounds
    var sounds = [];
    sounds['landing'] = game.add.audio('landing');
    sounds['steps'] = game.add.audio('steps');
    sounds['jump1'] = game.add.audio('jump1');
    sounds['jump2'] = game.add.audio('jump2');
    sounds['ouch1'] = game.add.audio('ouch1');
    sounds['ouch2'] = game.add.audio('ouch2');
    sounds['ouch3'] = game.add.audio('ouch3');
    sounds['ouch4'] = game.add.audio('ouch4');
    sounds['ouch5'] = game.add.audio('ouch5');
    sounds['ouch6'] = game.add.audio('ouch6');
    sounds['ouch7'] = game.add.audio('ouch7');
    sounds['ouch8'] = game.add.audio('ouch8');
    sounds['pop1'] = game.add.audio('pop1');
    sounds['pop2'] = game.add.audio('pop2');
    sounds['pop3'] = game.add.audio('pop3');
    sounds['pop4'] = game.add.audio('pop4');
    sounds['pop5'] = game.add.audio('pop5');
    sounds['pop6'] = game.add.audio('pop6');
    this.sounds = sounds;

    // - background
    this.background = game.add.tileSprite(0, 0, 960, 600, 'background');
    this.background.fixedToCamera = true;
    game.stage.backgroundColor = "#cfe6fe";

    // - creating groups
    this.grassBack = game.add.group();
    this.cloudsBack = game.add.group();

    this.ground = game.add.group();

    var platforms = game.add.group();
    platforms.enableBody = true;
    this.platforms = platforms;

    var clouds = game.add.group();
    clouds.enableBody = true;
    this.clouds = clouds;

    var hedgehogs = game.add.group();
    hedgehogs.enableBody = true;
    this.hedgehogs = hedgehogs;

    var bubbles = game.add.group();
    bubbles.enableBody = true;
    this.bubbles = bubbles;

    this.burstedBubbles = game.add.group();
    this.grassFront = game.add.group();

    // - creating player object
    this.createPlayer();

    game.camera.follow(this.player.bodySprite);
    game.camera.deadzone = new Phaser.Rectangle(320, 100, 100, 100);

    // - groups - continuation
    this.cloudsFront = game.add.group();

    this.createGround(levelData.ground);
    this.createLedges(levelData.ledges);
    this.createClouds(levelData.clouds);
    this.createHedgehogs(levelData.hedgehogs);
    this.createBubbles(levelData.bubbles);

    // - interface elements
    var scoreText = game.add.text(21, 13, "", { fontSize: '36px', fill: '#000'} );
    scoreText.alpha = 0.7;
    scoreText.fixedToCamera = true;
    this.scoreText = scoreText;

    var endText = game.add.text(21, 70, "", { fontSize: '36px', fill: '#eee'} );
    endText.fixedToCamera = true;
    this.endText = endText;

    this.soundButton = game.add.button(850, 10, 'speaker_icon', this.toggleSound, this, null, null, null, null);
    this.soundButton.fixedToCamera = true;
    this.soundButton.frame = 0;

    this.updateTexts();
}
