/*
 *    Copyright (c) 2016 by  Maciej Wiecierzewski
 */

GameState.prototype.update = function()
{
    var game = this.game;

    var player = this.player;
    var playerSprite = this.player.sprite;
    var playerBody = this.player.bodySprite;

    var platforms = this.platforms;
    var ground = this.ground;
    var clouds = this.clouds;
    var hedgehogs = this.hedgehogs;
    var bubbles = this.bubbles;

    var hedgehogColl = this.hedgehogCollisionObject;

    hedgehogs.callAll('updateVelocity');

    // collisions
    game.physics.arcade.collide(hedgehogs, platforms);

    game.physics.arcade.overlap(playerSprite, bubbles, this.burstBubble, null, this);
    playerBody.body.touching.down = false;

    game.physics.arcade.collide(playerBody, platforms, this.platformCollision, null, this);
    game.physics.arcade.collide(playerBody, clouds, this.cloudCollision, null, this);
    game.physics.arcade.collide(playerBody, ground);

    game.physics.arcade.overlap(playerBody, hedgehogs, this.hedgehogCollision, null, this);

    // when player is locked in a cloud
    if(player.locked)
    {
        playerBody.body.velocity.y = 0;

        if(this.checkLock() === false)
        {
            this.cancelLock();
            player.animation.fall();
            player.walking = false;
        }
    }

    var onGround = (playerBody.body.touching.down || this.player.locked);

    // sets in falling state
    if(!onGround && player.onGround === true)
    {
        player.animation.fall();
        player.onGround = false;
        player.walking = false;
    }

    //------ changing player position starts here ------

    playerBody.body.velocity.x = 0;

    // bouncing back on hedgehog collisions
    if(--hedgehogColl.count > 0)
        playerBody.body.velocity.x = hedgehogColl.posChange*100;
    else
        hedgehogColl.side = '';

    var cursors = game.input.keyboard.createCursorKeys();

    // moving left
    if(cursors.left.isDown && hedgehogColl.side !== 'left')
    {
        playerBody.body.velocity.x = -210;

        if(player.direction === 'right')    // flipping the player sprite
            playerSprite.scale.x *= -1;
        player.direction = 'left';

        if(onGround && player.walking === false)
        {
            player.animation.startWalk();
            player.walking = true;
        }
    }
    // moving right
    else if(cursors.right.isDown && hedgehogColl.side !== 'right')
    {
        playerBody.body.velocity.x = 210;

        if(player.direction === 'left')    // flipping the player sprite
            playerSprite.scale.x *= -1;
        player.direction = 'right';

        if(onGround && player.walking === false)
        {
            player.animation.startWalk();
            player.walking = true;
        }
    }

    // jumping
    if(cursors.up.isDown && onGround)
    {
        playerBody.body.velocity.y = -600;
        player.onGround = false;
        player.walking = false;

        if(player.locked)
            this.cancelLock();

        player.animation.jump();

        var i = Math.round(Math.random())+1;
        this.sounds['jump'+i].play();
    }

    // stop walking when no key press
    if(player.walking === true && !(cursors.left.isDown || cursors.right.isDown))
    {
       player.animation.stopWalk();
       player.walking = false;
    }
}
